@@ -116,9 +116,9 @@ class PosteClient:
     适配https://poste.io/
     """
 
-    def __init__(self, address, password, domain):
+    def __init__(self, address, password, domain, verify_ssl=True):
         self.uri = f'https://{domain}/admin/api/v1/'
-        self.client = httpx.Client(auth=(address, password))
+        self.client = httpx.Client(auth=(address, password), verify=verify_ssl)
 
     def __str__(self):
         return self.uri
@@ -152,7 +152,7 @@ class PosteClient:
         :return:
         """
         res = self.client.delete(url=f'{self.uri}boxes/{address}', timeout=(2, 2))
-        if res.status_code != 200:
+        if res.status_code != 204:
             raise Exception(f'delete_box res:{res.status_code},{res.text}')
 
     def init_box_client(self, email_prefix, password, domain=None) -> BoxClient:
